Struct VPKRespawn

pub struct VPKRespawn {
    pub header: VPKHeaderRespawn,
    pub tree: VPKTree<VPKDirectoryEntryRespawn>,
    pub archive_cams: HashMap<u16, VPKRespawnCam>,
}
Available on crate feature revpk only.
The Respawn VPK format.

Fields

header: VPKHeaderRespawn

The VPK’s header.

tree: VPKTree<VPKDirectoryEntryRespawn>

The tree of files in the VPK.

archive_cams: HashMap<u16, VPKRespawnCam>

The parsed CAM files for this VPK (external files, not included int dir.vpk file)

Implementations

Source

impl VPKRespawn

pub fn read_cam( &mut self, archive_index: u16, cam_path: &String, ) -> Result<(), String>

Reads a CAM file and adds it to the map of parsed CAMs for this VPK

pub fn read_all_cams( &mut self, archive_path: &String, vpk_name: &String, ) -> Result<(), String>

Reads all CAM files for this VPK and adds them to the map of parsed CAMs for this VPK